import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def bbone_resize(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Scale selected bendy bones display size

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Display Size
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def bend(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (0.0),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Bend selected items between the 3D cursor and the mouse

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def create_orientation(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        name: typing.Union[str, typing.Any] = "",
        use_view: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use: typing.Optional[typing.Union[bool, typing.Any]] = False,
        overwrite: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Create transformation orientation from selection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of the new custom orientation
    :type name: typing.Union[str, typing.Any]
    :param use_view: Use View, Use the current view instead of the active object to create the new orientation
    :type use_view: typing.Optional[typing.Union[bool, typing.Any]]
    :param use: Use After Creation, Select orientation after its creation
    :type use: typing.Optional[typing.Union[bool, typing.Any]]
    :param overwrite: Overwrite Previous, Overwrite previously created orientation with same name
    :type overwrite: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def delete_orientation(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Delete transformation orientation

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def edge_bevelweight(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Change the bevel weight of edges

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def edge_crease(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Change the crease of edges

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def edge_slide(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        single_side: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_even: typing.Optional[typing.Union[bool, typing.Any]] = False,
        flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_clamp: typing.Optional[typing.Union[bool, typing.Any]] = True,
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        correct_uv: typing.Optional[typing.Union[bool, typing.Any]] = True,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False):
    ''' Slide an edge loop along a mesh

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param single_side: Single Side
    :type single_side: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop
    :type use_even: typing.Optional[typing.Union[bool, typing.Any]]
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_clamp: Clamp, Clamp within the edge extents
    :type use_clamp: typing.Optional[typing.Union[bool, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming
    :type correct_uv: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def from_gizmo(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Transform selected items by mode type

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def mirror(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Mirror selected items around one or more axes

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def push_pull(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Push/Pull selected items

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Distance
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def resize(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
        mouse_dir_constraint: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        texture_space: typing.Optional[typing.Union[bool, typing.Any]] = False,
        remove_on_cancel: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False):
    ''' Scale (resize) selected items

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Scale
    :type value: typing.Optional[typing.Any]
    :param mouse_dir_constraint: Mouse Directional Constraint
    :type mouse_dir_constraint: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Optional[typing.Union[bool, typing.Any]]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def rotate(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        orient_axis: typing.Optional[typing.Union[str, int]] = 'Z',
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False):
    ''' Rotate selected items

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def rotate_normal(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        orient_axis: typing.Optional[typing.Union[str, int]] = 'Z',
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Rotate split normal of selected items

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def select_orientation(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        orientation: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL'):
    ''' Select transformation orientation

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param orientation: Orientation, Transformation orientation
    :type orientation: typing.Optional[typing.Union[str, int, typing.Any]]
    '''

    pass


def seq_slide(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (0.0, 0.0),
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        view2d_edge_pan: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Slide a sequence strip in time

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def shear(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        orient_axis: typing.Optional[typing.Union[str, int]] = 'Z',
        orient_axis_ortho: typing.Optional[typing.Union[str, int]] = 'X',
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Shear selected items along the given axis

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_axis_ortho: Axis Ortho
    :type orient_axis_ortho: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def shrink_fatten(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        use_even_offset: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False):
    ''' Shrink/fatten selected vertices along normals

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param use_even_offset: Offset Even, Scale the offset to give more even thickness
    :type use_even_offset: typing.Optional[typing.Union[bool, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def skin_resize(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
        orient_type: typing.Optional[typing.Union[str, int, typing.
                                                  Any]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int, typing.
                                                         Any]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Scale selected vertices' skin radii

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Scale
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def tilt(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Tilt selected control vertices of 3D curve

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def tosphere(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0,
                                                        0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Move selected items outward in a spherical shape around geometric center

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def trackball(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (0.0, 0.0),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Trackball style rotation of selected items

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def transform(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        mode: typing.Optional[typing.Union[str, int]] = 'TRANSLATION',
        value: typing.Optional[typing.Any] = (0.0, 0.0, 0.0, 0.0),
        orient_axis: typing.Optional[typing.Union[str, int]] = 'Z',
        orient_type: typing.Optional[typing.Union[str, int]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        snap_align: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_normal: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False,
        use_automerge_and_split: typing.Optional[typing.Union[bool, typing.
                                                              Any]] = False):
    ''' Transform selected items by mode type

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Optional[typing.Union[str, int]]
    :param value: Values
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param snap_align: Align with Point Normal
    :type snap_align: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_normal: Normal
    :type snap_normal: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge and Split
    :type use_automerge_and_split: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def translate(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        orient_type: typing.Optional[typing.Union[str, int]] = 'GLOBAL',
        orient_matrix: typing.Optional[typing.Any] = ((0.0, 0.0,
                                                       0.0), (0.0, 0.0, 0.0),
                                                      (0.0, 0.0, 0.0)),
        orient_matrix_type: typing.Optional[typing.Union[str, int]] = 'GLOBAL',
        constraint_axis: typing.Optional[
            typing.Union[typing.List[bool], typing.Any]] = (False, False,
                                                            False),
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_proportional_edit: typing.Optional[typing.Union[bool, typing.
                                                            Any]] = False,
        proportional_edit_falloff: typing.Optional[typing.
                                                   Union[str, int]] = 'SMOOTH',
        proportional_size: typing.Optional[typing.Any] = 1.0,
        use_proportional_connected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        use_proportional_projected: typing.Optional[typing.Union[bool, typing.
                                                                 Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        snap_align: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_normal: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        gpencil_strokes: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        cursor_transform: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        texture_space: typing.Optional[typing.Union[bool, typing.Any]] = False,
        remove_on_cancel: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        view2d_edge_pan: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False,
        use_automerge_and_split: typing.Optional[typing.Union[bool, typing.
                                                              Any]] = False):
    ''' Move selected items

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Move
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param snap_align: Align with Point Normal
    :type snap_align: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_normal: Normal
    :type snap_normal: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param cursor_transform: Transform Cursor
    :type cursor_transform: typing.Optional[typing.Union[bool, typing.Any]]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Optional[typing.Union[bool, typing.Any]]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge and Split
    :type use_automerge_and_split: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vert_crease(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Change the crease of vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vert_slide(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        value: typing.Optional[typing.Any] = 0.0,
        use_even: typing.Optional[typing.Union[bool, typing.Any]] = False,
        flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
        use_clamp: typing.Optional[typing.Union[bool, typing.Any]] = True,
        mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
        snap_elements: typing.Optional[typing.Any] = {'INCREMENT'},
        use_snap_project: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = False,
        snap_target: typing.Optional[typing.Union[str, int]] = 'CLOSEST',
        use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_snap_nonedit: typing.Optional[typing.Union[bool, typing.
                                                       Any]] = True,
        use_snap_selectable: typing.Optional[typing.Union[bool, typing.
                                                          Any]] = False,
        snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
        correct_uv: typing.Optional[typing.Union[bool, typing.Any]] = True,
        release_confirm: typing.Optional[typing.Union[bool, typing.
                                                      Any]] = False,
        use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
        alt_navigation: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False):
    ''' Slide a vertex along a mesh

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop
    :type use_even: typing.Optional[typing.Union[bool, typing.Any]]
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_clamp: Clamp, Clamp within the edge extents
    :type use_clamp: typing.Optional[typing.Union[bool, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap With
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming
    :type correct_uv: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param alt_navigation: Transform Navigation with Alt
    :type alt_navigation: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vertex_random(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        offset: typing.Optional[typing.Any] = 0.0,
        uniform: typing.Optional[typing.Any] = 0.0,
        normal: typing.Optional[typing.Any] = 0.0,
        seed: typing.Optional[typing.Any] = 0,
        wait_for_input: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = True):
    ''' Randomize vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param offset: Amount, Distance to offset
    :type offset: typing.Optional[typing.Any]
    :param uniform: Uniform, Increase for uniform offset distance
    :type uniform: typing.Optional[typing.Any]
    :param normal: Normal, Align offset direction to normals
    :type normal: typing.Optional[typing.Any]
    :param seed: Random Seed, Seed for the random number generator
    :type seed: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vertex_warp(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        warp_angle: typing.Optional[typing.Any] = 6.28319,
        offset_angle: typing.Optional[typing.Any] = 0.0,
        min: typing.Optional[typing.Any] = -1.0,
        max: typing.Optional[typing.Any] = 1.0,
        viewmat: typing.Optional[typing.Any] = ((0.0, 0.0, 0.0,
                                                 0.0), (0.0, 0.0, 0.0, 0.0),
                                                (0.0, 0.0, 0.0,
                                                 0.0), (0.0, 0.0, 0.0, 0.0)),
        center: typing.Optional[typing.Any] = (0.0, 0.0, 0.0)):
    ''' Warp vertices around the cursor

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param warp_angle: Warp Angle, Amount to warp about the cursor
    :type warp_angle: typing.Optional[typing.Any]
    :param offset_angle: Offset Angle, Angle to use as the basis for warping
    :type offset_angle: typing.Optional[typing.Any]
    :param min: Min
    :type min: typing.Optional[typing.Any]
    :param max: Max
    :type max: typing.Optional[typing.Any]
    :param viewmat: Matrix
    :type viewmat: typing.Optional[typing.Any]
    :param center: Center
    :type center: typing.Optional[typing.Any]
    '''

    pass



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def add_simple_uvs(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Add cube map UVs on mesh

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def add_texture_paint_slot(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Any] = 'BASE_COLOR',
        slot_type: typing.Optional[typing.Any] = 'IMAGE',
        name: typing.Union[str, typing.Any] = "Untitled",
        color: typing.Optional[typing.Any] = (0.0, 0.0, 0.0, 1.0),
        width: typing.Optional[typing.Any] = 1024,
        height: typing.Optional[typing.Any] = 1024,
        alpha: typing.Optional[typing.Union[bool, typing.Any]] = True,
        generated_type: typing.Optional[typing.Union[str, int]] = 'BLANK',
        float: typing.Optional[typing.Union[bool, typing.Any]] = False,
        domain: typing.Optional[typing.Union[str, int]] = 'POINT',
        data_type: typing.Optional[typing.Union[str, int]] = 'FLOAT_COLOR'):
    ''' Add a paint slot

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Material Layer Type, Material layer type of new paint slot
    :type type: typing.Optional[typing.Any]
    :param slot_type: Slot Type, Type of new paint slot
    :type slot_type: typing.Optional[typing.Any]
    :param name: Name, Name for new paint slot source
    :type name: typing.Union[str, typing.Any]
    :param color: Color, Default fill color
    :type color: typing.Optional[typing.Any]
    :param width: Width, Image width
    :type width: typing.Optional[typing.Any]
    :param height: Height, Image height
    :type height: typing.Optional[typing.Any]
    :param alpha: Alpha, Create an image with an alpha channel
    :type alpha: typing.Optional[typing.Union[bool, typing.Any]]
    :param generated_type: Generated Type, Fill the image with a grid for UV map testing
    :type generated_type: typing.Optional[typing.Union[str, int]]
    :param float: 32-bit Float, Create image with 32-bit floating-point bit depth
    :type float: typing.Optional[typing.Union[bool, typing.Any]]
    :param domain: Domain, Type of element that attribute is stored on
    :type domain: typing.Optional[typing.Union[str, int]]
    :param data_type: Data Type, Type of data stored in attribute
    :type data_type: typing.Optional[typing.Union[str, int]]
    '''

    pass


def brush_colors_flip(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Swap primary and secondary brush colors

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def brush_select(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        sculpt_tool: typing.Optional[typing.Union[str, int]] = 'DRAW',
        vertex_tool: typing.Optional[typing.Union[str, int]] = 'DRAW',
        weight_tool: typing.Optional[typing.Union[str, int]] = 'DRAW',
        image_tool: typing.Optional[typing.Union[str, int]] = 'DRAW',
        gpencil_tool: typing.Optional[typing.Union[str, int]] = 'DRAW',
        gpencil_vertex_tool: typing.Optional[typing.Union[str, int]] = 'DRAW',
        gpencil_sculpt_tool: typing.Optional[typing.
                                             Union[str, int]] = 'SMOOTH',
        gpencil_weight_tool: typing.Optional[typing.
                                             Union[str, int]] = 'WEIGHT',
        curves_sculpt_tool: typing.Optional[typing.Union[str, int]] = 'COMB',
        toggle: typing.Optional[typing.Union[bool, typing.Any]] = False,
        create_missing: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = False):
    ''' Select a paint mode's brush by tool type

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param sculpt_tool: sculpt_tool
    :type sculpt_tool: typing.Optional[typing.Union[str, int]]
    :param vertex_tool: vertex_tool
    :type vertex_tool: typing.Optional[typing.Union[str, int]]
    :param weight_tool: weight_tool
    :type weight_tool: typing.Optional[typing.Union[str, int]]
    :param image_tool: image_tool
    :type image_tool: typing.Optional[typing.Union[str, int]]
    :param gpencil_tool: gpencil_tool
    :type gpencil_tool: typing.Optional[typing.Union[str, int]]
    :param gpencil_vertex_tool: gpencil_vertex_tool
    :type gpencil_vertex_tool: typing.Optional[typing.Union[str, int]]
    :param gpencil_sculpt_tool: gpencil_sculpt_tool
    :type gpencil_sculpt_tool: typing.Optional[typing.Union[str, int]]
    :param gpencil_weight_tool: gpencil_weight_tool
    :type gpencil_weight_tool: typing.Optional[typing.Union[str, int]]
    :param curves_sculpt_tool: curves_sculpt_tool
    :type curves_sculpt_tool: typing.Optional[typing.Union[str, int]]
    :param toggle: Toggle, Toggle between two brushes rather than cycling
    :type toggle: typing.Optional[typing.Union[bool, typing.Any]]
    :param create_missing: Create Missing, If the requested brush type does not exist, create a new brush
    :type create_missing: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def face_select_all(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        action: typing.Optional[typing.Any] = 'TOGGLE'):
    ''' Change selection for all faces

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
    :type action: typing.Optional[typing.Any]
    '''

    pass


def face_select_hide(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        unselected: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Hide selected faces

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param unselected: Unselected, Hide unselected rather than selected objects
    :type unselected: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def face_select_less(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        face_step: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Deselect Faces connected to existing selection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param face_step: Face Step, Also deselect faces that only touch on a corner
    :type face_step: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def face_select_linked(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Select linked faces

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def face_select_linked_pick(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        deselect: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Select linked faces under the cursor

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param deselect: Deselect, Deselect rather than select items
    :type deselect: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def face_select_loop(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        select: typing.Optional[typing.Union[bool, typing.Any]] = True,
        extend: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Select face loop under the cursor

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param select: Select, If false, faces will be deselected
    :type select: typing.Optional[typing.Union[bool, typing.Any]]
    :param extend: Extend, Extend the selection
    :type extend: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def face_select_more(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        face_step: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Select Faces connected to existing selection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param face_step: Face Step, Also select faces that only touch on a corner
    :type face_step: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def face_vert_reveal(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        select: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Reveal hidden faces and vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param select: Select, Specifies whether the newly revealed geometry should be selected
    :type select: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def grab_clone(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        delta: typing.Optional[typing.Any] = (0.0, 0.0)):
    ''' Move the clone source image

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param delta: Delta, Delta offset of clone image in 0.0 to 1.0 coordinates
    :type delta: typing.Optional[typing.Any]
    '''

    pass


def hide_show(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        action: typing.Optional[typing.Any] = 'HIDE',
        area: typing.Optional[typing.Any] = 'INSIDE',
        xmin: typing.Optional[typing.Any] = 0,
        xmax: typing.Optional[typing.Any] = 0,
        ymin: typing.Optional[typing.Any] = 0,
        ymax: typing.Optional[typing.Any] = 0,
        wait_for_input: typing.Optional[typing.Union[bool, typing.
                                                     Any]] = True):
    ''' Hide/show some vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param action: Action, Whether to hide or show vertices * ``HIDE`` Hide -- Hide vertices. * ``SHOW`` Show -- Show vertices.
    :type action: typing.Optional[typing.Any]
    :param area: Area, Which vertices to hide or show * ``OUTSIDE`` Outside -- Hide or show vertices outside the selection. * ``INSIDE`` Inside -- Hide or show vertices inside the selection. * ``ALL`` All -- Hide or show all vertices. * ``MASKED`` Masked -- Hide or show vertices that are masked (minimum mask value of 0.5).
    :type area: typing.Optional[typing.Any]
    :param xmin: X Min
    :type xmin: typing.Optional[typing.Any]
    :param xmax: X Max
    :type xmax: typing.Optional[typing.Any]
    :param ymin: Y Min
    :type ymin: typing.Optional[typing.Any]
    :param ymax: Y Max
    :type ymax: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def image_from_view(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        filepath: typing.Union[str, typing.Any] = ""):
    ''' Make an image from biggest 3D view for reprojection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param filepath: File Path, Name of the file
    :type filepath: typing.Union[str, typing.Any]
    '''

    pass


def image_paint(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        stroke: typing.Optional[bpy.types.bpy_prop_collection[
            'bpy.types.OperatorStrokeElement']] = None,
        mode: typing.Optional[typing.Any] = 'NORMAL'):
    ''' Paint a stroke into the image

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param stroke: Stroke
    :type stroke: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorStrokeElement']]
    :param mode: Stroke Mode, Action taken when a paint stroke is made * ``NORMAL`` Regular -- Apply brush normally. * ``INVERT`` Invert -- Invert action of brush for duration of stroke. * ``SMOOTH`` Smooth -- Switch brush to smooth mode for duration of stroke.
    :type mode: typing.Optional[typing.Any]
    '''

    pass


def mask_box_gesture(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        xmin: typing.Optional[typing.Any] = 0,
        xmax: typing.Optional[typing.Any] = 0,
        ymin: typing.Optional[typing.Any] = 0,
        ymax: typing.Optional[typing.Any] = 0,
        wait_for_input: typing.Optional[typing.Union[bool, typing.Any]] = True,
        use_front_faces_only: typing.Optional[typing.Union[bool, typing.
                                                           Any]] = False,
        use_limit_to_segment: typing.Optional[typing.Union[bool, typing.
                                                           Any]] = False,
        mode: typing.Optional[typing.Any] = 'VALUE',
        value: typing.Optional[typing.Any] = 1.0):
    ''' Add mask within the box as you move the brush

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param xmin: X Min
    :type xmin: typing.Optional[typing.Any]
    :param xmax: X Max
    :type xmax: typing.Optional[typing.Any]
    :param ymin: Y Min
    :type ymin: typing.Optional[typing.Any]
    :param ymax: Y Max
    :type ymax: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_front_faces_only: Front Faces Only, Affect only faces facing towards the view
    :type use_front_faces_only: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
    :type use_limit_to_segment: typing.Optional[typing.Union[bool, typing.Any]]
    :param mode: Mode * ``VALUE`` Value -- Set mask to the level specified by the 'value' property. * ``VALUE_INVERSE`` Value Inverted -- Set mask to the level specified by the inverted 'value' property. * ``INVERT`` Invert -- Invert the mask.
    :type mode: typing.Optional[typing.Any]
    :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
    :type value: typing.Optional[typing.Any]
    '''

    pass


def mask_flood_fill(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        mode: typing.Optional[typing.Any] = 'VALUE',
        value: typing.Optional[typing.Any] = 0.0):
    ''' Fill the whole mask with a given value, or invert its values

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param mode: Mode * ``VALUE`` Value -- Set mask to the level specified by the 'value' property. * ``VALUE_INVERSE`` Value Inverted -- Set mask to the level specified by the inverted 'value' property. * ``INVERT`` Invert -- Invert the mask.
    :type mode: typing.Optional[typing.Any]
    :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
    :type value: typing.Optional[typing.Any]
    '''

    pass


def mask_lasso_gesture(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        path: typing.Optional[bpy.types.bpy_prop_collection[
            'bpy.types.OperatorMousePath']] = None,
        use_front_faces_only: typing.Optional[typing.Union[bool, typing.
                                                           Any]] = False,
        use_limit_to_segment: typing.Optional[typing.Union[bool, typing.
                                                           Any]] = False,
        mode: typing.Optional[typing.Any] = 'VALUE',
        value: typing.Optional[typing.Any] = 1.0):
    ''' Add mask within the lasso as you move the brush

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param path: Path
    :type path: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorMousePath']]
    :param use_front_faces_only: Front Faces Only, Affect only faces facing towards the view
    :type use_front_faces_only: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
    :type use_limit_to_segment: typing.Optional[typing.Union[bool, typing.Any]]
    :param mode: Mode * ``VALUE`` Value -- Set mask to the level specified by the 'value' property. * ``VALUE_INVERSE`` Value Inverted -- Set mask to the level specified by the inverted 'value' property. * ``INVERT`` Invert -- Invert the mask.
    :type mode: typing.Optional[typing.Any]
    :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
    :type value: typing.Optional[typing.Any]
    '''

    pass


def mask_line_gesture(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        xstart: typing.Optional[typing.Any] = 0,
        xend: typing.Optional[typing.Any] = 0,
        ystart: typing.Optional[typing.Any] = 0,
        yend: typing.Optional[typing.Any] = 0,
        flip: typing.Optional[typing.Union[bool, typing.Any]] = False,
        cursor: typing.Optional[typing.Any] = 5,
        use_front_faces_only: typing.Optional[typing.Union[bool, typing.
                                                           Any]] = False,
        use_limit_to_segment: typing.Optional[typing.Union[bool, typing.
                                                           Any]] = False,
        mode: typing.Optional[typing.Any] = 'VALUE',
        value: typing.Optional[typing.Any] = 1.0):
    ''' Add mask to the right of a line as you move the brush

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param xstart: X Start
    :type xstart: typing.Optional[typing.Any]
    :param xend: X End
    :type xend: typing.Optional[typing.Any]
    :param ystart: Y Start
    :type ystart: typing.Optional[typing.Any]
    :param yend: Y End
    :type yend: typing.Optional[typing.Any]
    :param flip: Flip
    :type flip: typing.Optional[typing.Union[bool, typing.Any]]
    :param cursor: Cursor, Mouse cursor style to use during the modal operator
    :type cursor: typing.Optional[typing.Any]
    :param use_front_faces_only: Front Faces Only, Affect only faces facing towards the view
    :type use_front_faces_only: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_limit_to_segment: Limit to Segment, Apply the gesture action only to the area that is contained within the segment without extending its effect to the entire line
    :type use_limit_to_segment: typing.Optional[typing.Union[bool, typing.Any]]
    :param mode: Mode * ``VALUE`` Value -- Set mask to the level specified by the 'value' property. * ``VALUE_INVERSE`` Value Inverted -- Set mask to the level specified by the inverted 'value' property. * ``INVERT`` Invert -- Invert the mask.
    :type mode: typing.Optional[typing.Any]
    :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
    :type value: typing.Optional[typing.Any]
    '''

    pass


def project_image(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        image: typing.Optional[typing.Union[str, int, typing.Any]] = ''):
    ''' Project an edited render from the active camera back onto the object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param image: Image
    :type image: typing.Optional[typing.Union[str, int, typing.Any]]
    '''

    pass


def sample_color(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        location: typing.Optional[typing.Any] = (0, 0),
        merged: typing.Optional[typing.Union[bool, typing.Any]] = False,
        palette: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Use the mouse to sample a color in the image

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param location: Location
    :type location: typing.Optional[typing.Any]
    :param merged: Sample Merged, Sample the output display color
    :type merged: typing.Optional[typing.Union[bool, typing.Any]]
    :param palette: Add to Palette
    :type palette: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def texture_paint_toggle(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Toggle texture paint mode in 3D view

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def vert_select_all(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        action: typing.Optional[typing.Any] = 'TOGGLE'):
    ''' Change selection for all vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
    :type action: typing.Optional[typing.Any]
    '''

    pass


def vert_select_hide(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        unselected: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Hide selected vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param unselected: Unselected, Hide unselected rather than selected vertices
    :type unselected: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vert_select_less(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        face_step: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Deselect Vertices connected to existing selection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param face_step: Face Step, Also deselect faces that only touch on a corner
    :type face_step: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vert_select_linked(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Select linked vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def vert_select_linked_pick(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        select: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Select linked vertices under the cursor

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param select: Select, Whether to select or deselect linked vertices under the cursor
    :type select: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vert_select_more(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        face_step: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Select Vertices connected to existing selection

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param face_step: Face Step, Also select faces that only touch on a corner
    :type face_step: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vert_select_ungrouped(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        extend: typing.Optional[typing.Union[bool, typing.Any]] = False):
    ''' Select vertices without a group

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param extend: Extend, Extend the selection
    :type extend: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vertex_color_brightness_contrast(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        brightness: typing.Optional[typing.Any] = 0.0,
        contrast: typing.Optional[typing.Any] = 0.0):
    ''' Adjust vertex color brightness/contrast

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param brightness: Brightness
    :type brightness: typing.Optional[typing.Any]
    :param contrast: Contrast
    :type contrast: typing.Optional[typing.Any]
    '''

    pass


def vertex_color_dirt(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        blur_strength: typing.Optional[typing.Any] = 1.0,
        blur_iterations: typing.Optional[typing.Any] = 1,
        clean_angle: typing.Optional[typing.Any] = 3.14159,
        dirt_angle: typing.Optional[typing.Any] = 0.0,
        dirt_only: typing.Optional[typing.Union[bool, typing.Any]] = False,
        normalize: typing.Optional[typing.Union[bool, typing.Any]] = True):
    ''' Generate a dirt map gradient based on cavity :File: `startup/bl_operators/vertexpaint_dirt.py\:179 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/vertexpaint_dirt.py#L179>`__

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param blur_strength: Blur Strength, Blur strength per iteration
    :type blur_strength: typing.Optional[typing.Any]
    :param blur_iterations: Blur Iterations, Number of times to blur the colors (higher blurs more)
    :type blur_iterations: typing.Optional[typing.Any]
    :param clean_angle: Highlight Angle, Less than 90 limits the angle used in the tonal range
    :type clean_angle: typing.Optional[typing.Any]
    :param dirt_angle: Dirt Angle, Less than 90 limits the angle used in the tonal range
    :type dirt_angle: typing.Optional[typing.Any]
    :param dirt_only: Dirt Only, Don't calculate cleans for convex areas
    :type dirt_only: typing.Optional[typing.Union[bool, typing.Any]]
    :param normalize: Normalize, Normalize the colors, increasing the contrast
    :type normalize: typing.Optional[typing.Union[bool, typing.Any]]
    '''

    pass


def vertex_color_from_weight(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Convert active weight into gray scale vertex colors

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def vertex_color_hsv(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        h: typing.Optional[typing.Any] = 0.5,
        s: typing.Optional[typing.Any] = 1.0,
        v: typing.Optional[typing.Any] = 1.0):
    ''' Adjust vertex color Hue/Saturation/Value

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param h: Hue
    :type h: typing.Optional[typing.Any]
    :param s: Saturation
    :type s: typing.Optional[typing.Any]
    :param v: Value
    :type v: typing.Optional[typing.Any]
    '''

    pass


def vertex_color_invert(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Invert RGB values

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def vertex_color_levels(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        offset: typing.Optional[typing.Any] = 0.0,
        gain: typing.Optional[typing.Any] = 1.0):
    ''' Adjust levels of vertex colors

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param offset: Offset, Value to add to colors
    :type offset: typing.Optional[typing.Any]
    :param gain: Gain, Value to multiply colors by
    :type gain: typing.Optional[typing.Any]
    '''

    pass


def vertex_color_set(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Fill the active vertex color layer with the current paint color

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def vertex_color_smooth(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Smooth colors across vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def vertex_paint(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        stroke: typing.Optional[bpy.types.bpy_prop_collection[
            'bpy.types.OperatorStrokeElement']] = None,
        mode: typing.Optional[typing.Any] = 'NORMAL'):
    ''' Paint a stroke in the active color attribute layer

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param stroke: Stroke
    :type stroke: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorStrokeElement']]
    :param mode: Stroke Mode, Action taken when a paint stroke is made * ``NORMAL`` Regular -- Apply brush normally. * ``INVERT`` Invert -- Invert action of brush for duration of stroke. * ``SMOOTH`` Smooth -- Switch brush to smooth mode for duration of stroke.
    :type mode: typing.Optional[typing.Any]
    '''

    pass


def vertex_paint_toggle(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Toggle the vertex paint mode in 3D view

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def weight_from_bones(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Any] = 'AUTOMATIC'):
    ''' Set the weights of the groups matching the attached armature's selected bones, using the distance between the vertices and the bones

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type, Method to use for assigning weights * ``AUTOMATIC`` Automatic -- Automatic weights from bones. * ``ENVELOPES`` From Envelopes -- Weights from envelopes with user defined radius.
    :type type: typing.Optional[typing.Any]
    '''

    pass


def weight_gradient(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Any] = 'LINEAR',
        xstart: typing.Optional[typing.Any] = 0,
        xend: typing.Optional[typing.Any] = 0,
        ystart: typing.Optional[typing.Any] = 0,
        yend: typing.Optional[typing.Any] = 0,
        flip: typing.Optional[typing.Union[bool, typing.Any]] = False,
        cursor: typing.Optional[typing.Any] = 5):
    ''' Draw a line to apply a weight gradient to selected vertices

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Any]
    :param xstart: X Start
    :type xstart: typing.Optional[typing.Any]
    :param xend: X End
    :type xend: typing.Optional[typing.Any]
    :param ystart: Y Start
    :type ystart: typing.Optional[typing.Any]
    :param yend: Y End
    :type yend: typing.Optional[typing.Any]
    :param flip: Flip
    :type flip: typing.Optional[typing.Union[bool, typing.Any]]
    :param cursor: Cursor, Mouse cursor style to use during the modal operator
    :type cursor: typing.Optional[typing.Any]
    '''

    pass


def weight_paint(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        stroke: typing.Optional[bpy.types.bpy_prop_collection[
            'bpy.types.OperatorStrokeElement']] = None,
        mode: typing.Optional[typing.Any] = 'NORMAL'):
    ''' Paint a stroke in the current vertex group's weights

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param stroke: Stroke
    :type stroke: typing.Optional[bpy.types.bpy_prop_collection['bpy.types.OperatorStrokeElement']]
    :param mode: Stroke Mode, Action taken when a paint stroke is made * ``NORMAL`` Regular -- Apply brush normally. * ``INVERT`` Invert -- Invert action of brush for duration of stroke. * ``SMOOTH`` Smooth -- Switch brush to smooth mode for duration of stroke.
    :type mode: typing.Optional[typing.Any]
    '''

    pass


def weight_paint_toggle(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Toggle weight paint mode in 3D view

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def weight_sample(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Use the mouse to sample a weight in the 3D view

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def weight_sample_group(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Select one of the vertex groups available under current mouse position

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass


def weight_set(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Fill the active vertex group with the current paint weight

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    pass
